#
# spec file for package man
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global         _sysconfdir %{_sysconfdir}
%global         _has_tmpfiled  %(rpm -q -f %{_prefix}/lib/tmpfiles.d | grep -c filesystem)
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
%define add_optflags(a:f:t:p:w:W:d:g:O:A:C:D:E:H:i:M:n:P:U:u:l:s:X:B:I:L:b:V:m:x:c:S:E:o:v:) \
%global optflags %{optflags} %{**}
%bcond_without  sdtimer
Name:           man
Version:        2.12.1
Release:        1.1
Summary:        A Program for Displaying man Pages
License:        GPL-2.0-or-later
Group:          System/Base
URL:            https://savannah.nongnu.org/projects/man-db
Source0:        https://download.savannah.gnu.org/releases/man-db/man-db-%{version}.tar.xz
Source1:        https://download.savannah.gnu.org/releases/man-db/man-db-%{version}.tar.xz.asc
Source2:        https://savannah.nongnu.org/people/viewgpg.php?user_id=10653#/%{name}.keyring
Source3:        sysconfig.cron-man
Source4:        cron.daily.do_mandb
Source5:        wrapper.c
Source6:        man-rpmlintrc
Source7:        man-db-create.service
Source8:        manpath.csh
Source9:        manpath.sh
Patch0:         man-db-2.3.19deb4.0-groff.dif
Patch3:         man-db-2.6.3-chinese.dif
# PATCH-FEATURE-OPENSUSE man-db-2.7.1-zio.dif -- Allow using libzio for decompression
Patch4:         man-db-2.7.1-zio.dif
# PATCH-FEATURE-OPENSUSE man-db-2.6.3-listall.dif -- If multiple matching pages are found show a list bnc#786679
Patch5:         man-db-2.6.3-listall.dif
# PATCH-FIX-SUSE Fixes build-compare bnc#971922
Patch6:         reproducible.patch
# PATCH-FIX-OPENSUSE man-db-2.9.4-no-chown.patch -- chown is not allowed as non-root
Patch7:         man-db-2.9.4-no-chown.patch
# PATCH-FIX-SUSE collections of changes
Patch8:         man-db-2.9.4.patch
# PATCH-FEATURE-OPENSUSE -- Add documentation about man0 section (header files)
Patch9:         man-db-2.6.3-man0.dif
# PATCH-FEATURE-OPENSUSE -- Propose to read man pages online
Patch12:        man-propose-online.patch
BuildRequires:  automake
BuildRequires:  flex
BuildRequires:  gdbm-devel
BuildRequires:  gettext-runtime
BuildRequires:  gettext-tools
BuildRequires:  groff
BuildRequires:  less
BuildRequires:  libalternatives-devel
BuildRequires:  libpipeline-devel >= 1.5.0
BuildRequires:  libzio-devel
BuildRequires:  lzip
BuildRequires:  man-pages
BuildRequires:  pkgconfig
BuildRequires:  po4a
BuildRequires:  zlib-devel
BuildRequires:  zstd
BuildRequires:  pkgconfig(systemd)
Conflicts:      mandoc
Requires:       glibc-locale-base
Suggests:       glibc-locale
Requires:       groff >= 1.18
Requires:       less
Requires(post): %fillup_prereq
Requires(pre):  coreutils
Requires(pre):  group(man)
Requires(pre):  user(man)
Provides:       man_db
%if 0%{?suse_version} < 1500
Requires:       cron
%endif

%description
A program for displaying man pages on the screen or sending them to a
printer (using groff).

%prep
%setup -q -n man-db-%{version}
%patch -P 0 -b .groff
%patch -P3 -b .chinese
%patch -P4 -b .zio
%patch -P5 -b .listall
%patch -P6 -p1 -b .p6
%patch -P7 -p1 -b .p7
%patch -P8 -p1 -b .p8
%patch -P9 -b .p9
rm -f configure
%patch -P12 -p1 -b .p12

%build
%global optflags %{optflags} -funroll-loops -pipe -Wall

gettextize --force --copy --no-changelog
SEC=(0 1 n l 8 3 2 5 4 9 6 7
	 1x 3x 4x 5x 6x 8x
	 1bind 3bind 5bind 7bind 8bind
	 1cn 8cn
	 1m 1mh 5mh 8mh
	 1netpbm 3netpbm 5netpbm
	 0p 1p 3p 3posix
	 1pgsql 3pgsql 5pgsql
	 3C++ 8C++
	 3blt
	 3curses 3ncurses 3form 3menu
	 3db 3gdbm 3f 3gk 3paper
	 3mm 5mm
	 3perl 3pm 3pq
	 3qt 3pub 3readline
	 1ssl 3ssl 5ssl 7ssl
	 3t 3tk 3tcl 3tclx 3tix
	 7l 7nr
	 8c
	 Cg g s m
)
SEC="${SEC[@]}"
for d in $(cat man/LINGUAS*) ; do
	test -d %{_datadir}/locale/$d || continue
	LINGUAS="${LINGUAS:+$LINGUAS }$d"
done
LIBS="-lalternatives"
export LINGUAS LIBS

# Hack as otherwise
# BuildRequires:  groff-full
# is required
mkdir bin
ln -sf /bin/true bin/refer
ln -sf /bin/true bin/w3m
PATH=$PATH:${PWD}/bin
export PATH

# Create configure
aclocal  -I ${PWD} -I ${PWD}/m4 -I ${PWD}/gl/m4
autoconf -B ${PWD} -B ${PWD}/m4 -B ${PWD}/gl/m4
automake --add-missing
find -name 'Makefile.*' | xargs \
	sed -ri -e '/^pkglibdir/{ s@^(pkglibdir[[:blank:]]+=[[:blank:]]+\$\(libdir\)).*@\1@p }'
# Configure
%add_optflags -D_GNU_SOURCE -D_DEFAULT_SOURCE -D_XOPEN_SOURCE=500
%configure \
%if %{without sdtimer}
	--with-systemdtmpfilesdir=no \
	--with-systemdsystemunitdir=no \
%endif
	--enable-cache-owner=man \
	--with-device=utf8		\
	--with-zio			\
	--with-gnu-ld			\
	--disable-rpath			\
	--disable-automatic-create	\
	--enable-automatic-update	\
	--enable-mandirs=GNU		\
	--disable-cats			\
	--enable-threads=posix		\
	--enable-mb-groff		\
	--with-db=gdbm			\
	--enable-nls			\
	--with-config-file=%{_sysconfdir}/manpath.config \
	--with-sections="${SEC}"
%make_build nls=all LOCALE_FR_UTF8=fr_FR.UTF-8
# Fix coding
for man in $(find man/ -type f -a -name '*.[0-9]'); do
	pp="$(head -n 1 $man)"
	case "$pp" in
	\'\\\"*\ -\*-\ coding:\ *\ -\*-)
	    continue
	    ;;
	\'\\\"*)
	    sed -ri "1{ s/('\\\\\".*)/\\1 -\*- coding: UTF-8 -\*-/ }" $man
	    ;;
	*)
	    sed -ri "1 i\
		'\\\\\" -\*- coding: UTF-8 -\*-\
		"  $man
	esac
done
#
gcc $CFLAGS -I gl/lib/ -I include/ --include config.h \
	-D LOCALEDIR="\"%{_datarootdir}/locale\"" \
	-D LIBEXECDIR="\"%{_libexecdir}\"" -o wrapper %{SOURCE5} -L gl/lib/.libs/ -lgnu

%check
if ! make check; then
	cat src/tests/test-suite.log
	exit 1
fi

%install
%if 0%{?suse_version} <= 1030
    export MKDIR_P="mkdir -p"
%endif
rm -rf   %{buildroot}%{_localstatedir}/cache/man
%make_install nls=all LOCALE_FR_UTF8=fr_FR.UTF-8
find %{buildroot} -type f -name "*.la" -delete -print
# Move manual
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/man-db %{buildroot}%{_docdir}/man/
# wrapper which drops roots privileges if root executes mandb
mv -vf   %{buildroot}%{_bindir}/mandb        %{buildroot}%{_libexecdir}/man-db/
install -D -m 0755 wrapper %{buildroot}%{_libexecdir}/man-db/
ln -sf   %{_libexecdir}/man-db/wrapper       %{buildroot}%{_bindir}/mandb
# Fix man pages
pushd %{buildroot}%{_mandir}/
rm -rf *.ascii/
for d in *.UTF-8 ; do
	find -name '*.[1-9nlop]' | xargs gzip -9f
done
for d in $(find -name manpath.5%{?ext_man} -printf '%%h ') ; do
	ln -sf manpath.5%{?ext_man} $d/manpath.config.5%{?ext_man}
done
# remove japanese pages, as they are in man-pages-ja
# (need to cross verify at some point that they are up to date there)
rm -rf ja
popd

install -m 644 src/man_db.conf %{buildroot}%{_sysconfdir}/manpath.config
sh ./mk_catdirs %{buildroot}
mkdir -p %{buildroot}%{_datadir}/groff/site-tmac
install -m 0644 groff/tmac.andb     %{buildroot}%{_datadir}/groff/site-tmac/
install -m 0644 groff/tmac.andocdb  %{buildroot}%{_datadir}/groff/site-tmac/
mkdir -p %{buildroot}%{_fillupdir}
mkdir -p %{buildroot}%{_unitdir}/
%if 0%{?suse_version} < 1500
    mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
%endif
    install -m 0644 %{SOURCE3} %{buildroot}%{_fillupdir}
%if 0%{?suse_version} < 1500
    install -m 0744 %{SOURCE4} %{buildroot}%{_sysconfdir}/cron.daily/suse-do_mandb
%else
    install -m 0744 %{SOURCE4} %{buildroot}/%{_libexecdir}/man-db/do_mandb
%endif
%if %{with sdtimer}
    install -m 0644 %{SOURCE7} %{buildroot}%{_unitdir}/
%endif

mkdir -p %{buildroot}%{_prefix}/etc/profile.d
install -m 644 %{SOURCE8} %{buildroot}%{_prefix}/etc/profile.d/
install -m 644 %{SOURCE9} %{buildroot}%{_prefix}/etc/profile.d/

%find_lang man-db --all-name --with-man

%global trigger_functions %{expand:
-- Check if rpm.execute() as function call is given
if type(rpm.execute) == "function" then
   execute = rpm.execute
else
  function execute(path, ...)
    local pid = posix.fork()
    if not pid then
       error(path .. ": fork failed: " .. posix.errno() .. "\n")
    elseif pid == 0 then
       assert(posix.exec(path, ...))
    else
       posix.wait(pid)
    end
  end
end
--
}

%if 0%{?suse_version} >= 1699
%transfiletriggerin -p <lua> -- %{_mandir}
%else
%filetriggerin -p <lua> -- %{_mandir}
%endif
%trigger_functions
stat = posix.stat("%{_localstatedir}/cache/man/index.db")
if stat then
    execute("%{_bindir}/mandb", "--quiet")
else
    domkdir = false
    stat = posix.stat("%{_localstatedir}/cache/man")
    if not stat then
        domkdir = true
    elseif not (stat.type == "directory") then
        domkdir = true
        os.remove("%{_localstatedir}/cache/man")
    end
    if domkdir then
        posix.mkdir("%{_localstatedir}/cache/man")
        posix.chown("%{_localstatedir}/cache/man", "man", "man")
    end
    execute("%{_bindir}/mandb", "--quiet", "--create")
end

%if 0%{?suse_version} >= 1699
%transfiletriggerpostun -p <lua> -- %{_mandir}
%else
%filetriggerpostun -p <lua> -- %{_mandir}
%endif
%trigger_functions
stat = posix.stat("%{_localstatedir}/cache/man/index.db")
if stat then
    execute("%{_bindir}/mandb", "--quiet")
else
    domkdir = false
    stat = posix.stat("%{_localstatedir}/cache/man")
    if not stat then
        domkdir = true
    elseif not (stat.type == "directory") then
        domkdir = true
        os.remove("%{_localstatedir}/cache/man")
    end
    if domkdir then
        posix.mkdir("%{_localstatedir}/cache/man")
        posix.chown("%{_localstatedir}/cache/man", "man", "man")
    end
    execute("%{_bindir}/mandb", "--quiet", "--create")
end

%pre
test -d var/catman/ && rm -rf var/catman/ || true
%if %{with sdtimer}
%if 0%{?suse_version} >= 1500
%service_add_pre man-db-create.service man-db.service man-db.timer
%else
%service_add_pre man-db-create.service
%endif
%endif
if test "$1" -gt 0 -a -h %{_sysconfdir}/alternatives/man
then
  for ua in man apropos whatis man.1%{ext_man} apropos.1%{ext_man} whatis.1%{ext_man}
  do
    rm -f %{_sysconfdir}/alternatives/$ua
    case "$ua" in
    *.1*)
      rm -f %{_mandir}/man1/$ua
      ;;
    *)
      rm -f %{_bindir}/$ua
      ;;
    esac
  done
fi
# With fallback for systemdless containers
if test ! -d %{_localstatedir}/cache/man
then
  # Simply for systemdless containers
  umask 022
  rm -f %{_localstatedir}/cache/man
  mkdir -p %{_localstatedir}/cache/man
  chown -R man:man %{_localstatedir}/cache/man
fi

%post
%{fillup_only -an cron}
/sbin/ldconfig
%if %{with sdtimer}
%service_add_post man-db-create.service
%if 0%{?suse_version} >= 1500
%service_add_post man-db.service man-db.timer
%endif
%endif

%preun
%if %{with sdtimer}
%service_del_preun man-db-create.service
%if 0%{?suse_version} >= 1500
%service_del_preun man-db.service man-db.timer
%endif
%endif

%postun
/sbin/ldconfig
%if %{with sdtimer}
%service_del_postun man-db-create.service
%if 0%{?suse_version} >= 1500
%service_del_postun man-db.service man-db.timer
%endif
%endif

%posttrans
if test ! -s %{_localstatedir}/cache/man/index.db
then
  mandb --quiet --create || :
fi

%files -f man-db.lang
%license COPYING
%doc ChangeLog
%doc %{_docdir}/man/man-db-manual*
%config %{_sysconfdir}/manpath.config
%if 0%{?suse_version} < 1500
%attr(0744,root,root) %{_sysconfdir}/cron.daily/suse-do_mandb
%endif
%dir %{_prefix}/etc/profile.d/
%{_prefix}/etc/profile.d/manpath.*
%{_bindir}/apropos
%{_bindir}/catman
%{_bindir}/lexgrog
%{_bindir}/man
%{_bindir}/mandb
%{_bindir}/manpath
%{_bindir}/man-recode
%{_bindir}/whatis
%dir %attr(0755,root,root) %{_libexecdir}/man-db
%attr(0755,root,root) %{_libexecdir}/man-db/mandb
%attr(0755,root,root) %{_libexecdir}/man-db/manconv
%attr(0755,root,root) %{_libexecdir}/man-db/globbing
%attr(0755,root,root) %{_libexecdir}/man-db/wrapper
%if 0%{?suse_version} >= 1500
%attr(0755,root,root) %{_libexecdir}/man-db/do_mandb
%endif
%{_sbindir}/accessdb
%{_libdir}/libman*.so
%{_libexecdir}/man-db/zsoelim
%if 0%{?_has_tmpfiled} == 0
%dir %{_prefix}/lib/tmpfiles.d
%endif
%{_prefix}/lib/tmpfiles.d/man-db.conf
%if %{with sdtimer}
%{_unitdir}/man-db-create.service
%if 0%{?suse_version} >= 1500
%{_unitdir}/man-db.service
%{_unitdir}/man-db.timer
%endif
%endif
%dir %{_datadir}/groff/site-tmac
%{_datadir}/groff/site-tmac/tmac.andb
%{_datadir}/groff/site-tmac/tmac.andocdb
%{_mandir}/man1/*.1%{?ext_man}
%{_mandir}/man5/*.5%{?ext_man}
%{_mandir}/man8/*.8%{?ext_man}
%dir %{_mandir}/id
%dir %{_mandir}/sr
%dir %{_mandir}/ro
%dir %{_mandir}/tr
%{_fillupdir}/sysconfig.cron-man
%defattr(-,man,man)
%ghost %{_localstatedir}/cache/man

%changelog
* Tue Jun  4 2024 Dr. Werner Fink <werner@suse.de>
- Update to 2.12.1 (5 April 2024)
  * Fix excessive cleanup of `/var/cache/man` by `systemd-tmpfiles`.
  * `man` matches the display width more accurately to the configured width.
  * Upgrade to Gnulib `stable-202401`.
  * Mention `groff`'s `pdf` device in `man(1)`.
  * Speed up `seccomp` filter slightly.
  * Document how to format pages using italic rather than underlined text.
  * Remove the obsolete `chconfig` tool for converting man-db configuration
    files to the FHS.  This transition took place almost 25 years ago (at
    least in Debian), so it's not worth keeping it around now.
- Remove patch man-db-2.9.4-alternitive.dif now upstream
- Port the patches
  * man-db-2.6.3-listall.dif
  * man-db-2.7.1-zio.dif
  * man-db-2.9.4.patch
  * man-propose-online.patch
* Mon Feb 19 2024 Dr. Werner Fink <werner@suse.de>
- We don't need anymore systemd-tmpfiles (boo#1219370#c13)
* Mon Feb 12 2024 Dr. Werner Fink <werner@suse.de>
- Move creation of /var/cache/man into %%pre scriplet (boo#1219370)
* Thu Feb  8 2024 Dr. Werner Fink <werner@suse.de>
- Make lua scriplets more failsafe (boo#1219370)
* Fri Jan 26 2024 Dr. Werner Fink <werner@suse.de>
- Skip posttrans dependency on systemd to support container without
  systemd (boo#1215538)
- Use %%(trans)filetriggerin and %%(trans)filetriggerpostun to get
  an uptodate man database for installed manual pages
* Sun Oct  1 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Update to 2.12.0:
  * Fix some manual page portability issues with groff 1.23.0.
  * Fix test failures when a working `iconv` is not available.
  * Ensure that timestamps read from the database can go past the year 2038,
    even on systems where this is not the default.
  * Fix `manpath` not parsing `PATH` entries with trailing slash correctly
    for guessing `MANPATH` entries.
  * More accurately document the behaviour of passing file names as arguments
    to `man` without the `-l`/`--local-file` option.
  * Avoid duplicate cleanup of old cat pages by both `man-db.service` and
    `systemd-tmpfiles-clean.service`.
  Improvements:
  * Update system call lists in `seccomp` sandbox from `systemd`.
  * Upgrade to Gnulib `stable-202307`.
  * Work around the Firebuild accelerator in `seccomp` sandbox: if this is in
    use then we need to allow some socket-related system calls.
  * `man -K` now deduplicates search results that point to the same page.
  * Warn if `mandb` drops to `--user-db` mode due to running as the wrong
    user.
  * Change section title recommendations in `man(1)` to mention `STANDARDS`
    rather than `CONFORMING TO`, in line with `man-pages(7)`.
  * Add a `STANDARDS` section to `man(1)` itself.
  * Document that `man -K` may suffer from false negatives as well as false
    positives.
  * Take advantage of newer `groff` facilities to implement `man
  - -no-hyphenation` and `man --no-justification`, if available.
  * `man -f` and `man -k` now pass any `-r`/`--regex` or `-w`/`--wildcard`
    options on to `whatis` and `apropos` respectively.
  * Always pass a line length to `nroff`, even if we believe that it matches
    the default.
  * Allow disabling `groff` warnings via `man --warnings`, by prefixing a
    warning name with `!`.
- Drop man-db-groff-1.23.0-warnings.patch
- Refresh man-db-2.9.4.patch
* Fri Sep  8 2023 Antonio Teixeira <antonio.teixeira@suse.com>
- Add man-db-groff-1.23.0-warnings.patch
  * Fix build errors with groff 1.23.0
* Sat Aug 26 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Fix the content in patch file man-propose-online.patch
* Tue Aug 15 2023 Dr. Werner Fink <werner@suse.de>
- Update to 2.11.2:
  * Fix compile and test failures when `troff` is not `groff`.
  * Fix segfault in typical uses of `man` when `nroff` is not installed.
  * Fix crash in `mandb` when processing stray cats.
  * SECURITY: Replace `$` characters in page names with `?` when constructing
    `less` prompts.
  * Silence error message when processing an empty manual page hierarchy with
    a nonexistent cache directory.
  * `man(1)` now sorts whatis references below real pages, even if the whatis
    references are from a section with higher priority.
  * `mandb` now correctly records filters in the database if it uses cached
    whatis information.
  * Upgrade Gnulib, fixing syntax error on glibc systems with GCC 11.
  * The `CATWIDTH` configuration file directive now overrides `MINCATWIDTH`
    and `MAXCATWIDTH`.
  * Database entries for links were often incorrectly stored as if they were
    entries for the ultimate source of the page.  They are now stored with
    the correct type.
  * Store links in the database using the section and extension of the link
    rather than of the ultimate source file.
  * Consider pages for adding to the database even if they seem to already
    exist; this performance optimization is no longer needed due to caching,
    and it produced inconsistent results in some unusual cases.
  * `man` now runs any required preprocessors in the same order that `groff`
    does, rather than trusting the order of filters in a page's preprocessor
    string.
  * Fix building on MinGW.  (I haven't been able to test this; help from
    MinGW experts would be welcome.)
  Improvements:
  * Check for stray cats even if no manual pages in a given manpath were
    changed.
  * Add section `3type` to the default section list just after `2`.  This is
    used by the Linux man-pages package.
  * Recognize more Hungarian translations of the `NAME` section.
  * Add more recognized case variants for localized versions of the `NAME`
    section.
  * Maintain multi keys in sorted order, improving database reproducibility.
  * Pick a more consistent name for the target of a whatis entry in the
    database.
  * Extend rules for when to replace one database entry with another,
    producing more stable behaviour.
  * Fully reorganize databases after writing them, allowing the reproduction
    of bitwise-identical databases regardless of scan order (at least with
    GDBM).
- Port patches
  * man-db-2.6.3-chinese.dif
  * man-db-2.6.3-listall.dif
  * man-db-2.7.1-zio.dif
  * man-db-2.9.4-alternitive.dif
  * man-db-2.9.4-no-chown.patch
  * man-db-2.9.4.patch
  * man-propose-online.patch
* Thu May 25 2023 Dr. Werner Fink <werner@suse.de>
- Remove harden_man-db.service.patch as already done upstream
  at the end of the service file man-db.service
* Mon Apr  3 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add man-propose-online.patch: if patch was not found locally,
  propose to read it online, offering a URL where it could possibly
  be found.
* Tue Aug 23 2022 Dr. Werner Fink <werner@suse.de>
- Corrrect some offsets of patch hunks
- Remove change in get-mtime.c as mandb-symlink-target-timestamp
  now catch the random format changes
* Mon Aug 22 2022 Dirk Müller <dmueller@suse.com>
- update to 2.10.2:
  * Regenerating man-db's build system now explicitly requires Automake >=
    1.14.  (This was already the case since at least man-db 2.10.0, but was
    previously undocumented.)
  * Make `man -H` sleep for a few seconds after starting the browser, since
    it may background itself before loading files (Dr. Werner Fink).
  * If an override directory is configured using `--with-override-dir`, it is
    now applied more consistently when building the manpath, and whether a
    page was found in an override directory is considered when sorting
    candidates for display (Mihail Konev).
  * Make the man-db manual build reproducible.
  * Add some hardening options to the `systemd` service.
  * `configure` now has a `--with-snapdir` option, for use on systems where
    `snapd` is configured to use a directory other than `/snap`.
  * Fix occasional `mandb-symlink-target-timestamp` test failure.
  * Fix inadvertent reliance on a GCC extension that caused build failures
    with Clang.
  * Fix building without `iconv`.
- drop man-db-2.7.1-firefox.dif (upstream)
* Thu Aug 18 2022 Dr. Werner Fink <werner@suse.de>
- Avoid that mandb-symlink-target-timestamp fools us
* Thu Aug 18 2022 Dr. Werner Fink <werner@suse.de>
- Workaround missing groff-full to get refer(1), the bibliographic
  preprocessor found
* Thu Aug 18 2022 Dr. Werner Fink <werner@suse.de>
- Update to man-db 2.10.0 (4 February 2022)
  * Manpath deduplication no longer mishandles the case where another entry
    in the manpath is a suffix of a candidate path to append.
  * Fix potential crash in path searching if `getcwd` fails for reasons other
    than running out of memory.
  * Fix crash in `globbing` test tool if run with no non-option arguments.
  * `lexgrog` now produces output in the user's locale.
  * Downgrade "malformed .lf request" warning to a debug message and rephrase
    it somewhat, since `.lf` requests can use `*roff` arithmetic expressions
    and we can't reasonably parse those.
  * Avoid modifying the database without changing its mtime, which had been
    possible since 2.7.0 if `mandb`'s purge phase found work to do but the
    main phase didn't, and which confused some backup systems into reporting
    possible filesystem corruption.
  * `man` no longer inadvertently modifies the `MANSECT` environment variable
    before passing it on to its subprocesses.
  * `mandb` now stores the mtime of link targets as the mtime of their
    corresponding database entries, rather than sometimes storing the mtime
    of the link instead.
  * Since man-db 2.4.2, `man` has behaved as if the `-l` option was given if
    a manual page argument contains a slash.  Since man-db 2.5.6, this has
    interacted slightly poorly with the subpage feature, emitting spurious
    error messages if given multiple manual page arguments some of which
    include a slash.  `man` no longer emits spurious error messages in this
    case.
  * Reduce overhead of `MAN_DISABLE_SECCOMP=1` compared to building without
    `libseccomp`.
  * Document `MAN_DISABLE_SECCOMP` and `PIPELINE_DEBUG` environment variables
    in `man(1)`.
  * Add `man-pages(7)` reference to `man(1)`.
  * Recognize Arabic and Persian translations of the `NAME` section.
  * Delay the `systemd` timer using `RandomizedDelaySec`, so that multiple
    containers/VMs on the same host are less prone to running `mandb` all at
    the same time.
  * Significantly improve `mandb(8)` and `man -K` performance in the common
    case where pages are of moderate size and compressed using `zlib`: `mandb
  - c` goes from 344 seconds to 10 seconds on a test system.
- Remove patch man-db-2.7.1-security4.dif as now upstream creates
  any missing database
- Remove gnulib-ppc64le.patch as gnulib is uptodate even on ppc64le
- Port patches
  * man-db-2.6.3-chinese.dif
  * man-db-2.6.3-listall.dif
  * man-db-2.6.3-man0.dif
  * man-db-2.7.1-zio.dif
  * man-db-2.9.4-alternitive.dif
  * man-db-2.9.4-no-chown.patch
  * man-db-2.9.4.patch
  * reproducible.patch
* Mon Aug 15 2022 <d_werner@gmx.net>
- syntax correction of the preinstall scriptlet to avoid creation
  of file /0 (bnc#1202377)
* Thu Aug 11 2022 Dr. Werner Fink <werner@suse.de>
- Add patch gnulib-ppc64le.patch
  * Support ppc64le float128 transition
* Thu Aug 11 2022 Dr. Werner Fink <werner@suse.de>
- Drop usage of update-alternatives as mandoc does not use it
  (nor libalternative)
* Sat May  7 2022 Marcus Meissner <meissner@suse.com>
- switch source url to https
* Wed Oct  6 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_man-db.service.patch
  Modified:
  * man-db-create.service
* Fri Aug  6 2021 Dr. Werner Fink <werner@suse.de>
- Add manpath.sh and manpath.csh below /usr/etc/profile.d
* Mon May 31 2021 Stefan Schubert <schubi@suse.de>
- Add patch man-db-2.9.4-alternitive.dif
  * Supporting ALSO new `alternatives` which has the same tasks as
    `update-alternatives` but in a simplier way.
* Mon May 31 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.9.4:
  * Add support for zstd-compressed manual pages
  * Recognise Esperanto, Romanian, Tamil, and Ukrainian translations
    of the NAME section.
  * Fix handling of \- in the right-hand side of a NAME section.
  * Treat "\[en]" (etc.) as another synonym for "\-" in NAME sections,
    alongside the existing "\(en" (etc.).
  * Avoid incorrect markup in man(1) with po4a >= 0.58.
  * Fix manual page translation infrastructure to compare po4a
    versions with more than two components correctly.
  * Fix "man -X75-12" and "man -X100-12" to set the document font
    size as well as the device
  * Fix incompatibility of "man -X" and friends with the seccomp
    sandbox.
  * man --recode and manconv now adjust encoding declarations on the
    first line of their input to refer to the new encoding.
  * There is a new "man-recode" program. Which has an interface
    designed for bulk conversion and so can be much faster when
    used on a large number of pages.
  * Fix comparison of candidate manual pages to correctly handle the
    case where the language elements are the same and match the
    locale, but the territory elements differ.
  * If run with no arguments or only a section, man now suggests
    running "man man".
  * man now understands the <page>(<section>) form on its command
    line, so for example "man 'chmod(2)'" is now the same as
    "man 2 chmod".
  * manconv now guesses the input encoding based on the file name
    if it is not explicitly specified.
  * Further workarounds for ESET File Security: allow sendmsg when
    it is in use.
  * If more than one of "../man", "man", "../share/man", and
    "share/man" exist relative to a directory on $PATH, then all of
    them are now added to the automatically-determined manpath
  * Remove arbitrary limit on manpath size.
  * Fix several resource and memory leaks.
  * Ship a systemd timer to perform daily database maintenance.
  * Fix segfaults in mandb.
- Drop our systemd timer in favor of upstream provided one
- Drop unused mancoding
- Drop upstream fixed man-db-2.6.3-section.dif
- Merge man-MAN_POSIXLY_CORRECT-man1.dif into
  man-db-2.6.3-listall.dif as first one is only the documentation
  of the latter one
- Seperate man-db-2.9.4-no-chown.patch from man-db-2.8.4.dif
- Update man-db-2.8.4.dif, now called man-db-2.9.4.patch
- Update man-db-2.6.3-man0.dif to be used inside prep section
- Refresh man-db-2.7.1-security4.dif, man-db-2.7.1-zio.dif
* Fri Jan 22 2021 Dirk Müller <dmueller@suse.com>
- require only glibc-locale-base
* Fri Sep 11 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Add migration code to handle upgrade from old version of the man
  package not supporting alternative path move (boo#1175919).
* Sun Aug 30 2020 Antoine Belvire <antoine.belvire@opensuse.org>
- Fix usage of update-alternatives (boo#1175919).
* Thu Aug 27 2020 Ludwig Nussel <lnussel@suse.de>
- Don't recommend groff-full to avoid pulling in ghostscript etc.
  groff-full installs itself when there's groff and
  ghostscript-library installed.
* Thu Aug 27 2020 Dr. Werner Fink <werner@suse.de>
- Set libexecdir at build time for wrapper (boo#1175813)
- Do the same in mandb.service
* Mon Jun 15 2020 Dr. Werner Fink <werner@suse.de>
- Allow user man to execute the do_mandb script (boo#1172876)
* Fri Jun  5 2020 Dr. Werner Fink <werner@suse.de>
- Switch to user:group man:man within mandb.service (boo#1172575)
* Sun May 17 2020 Andreas Stieger <andreas.stieger@gmx.de>
- add upstream signing keys and verify source signature
* Thu Jan  9 2020 Ludwig Nussel <lnussel@suse.de>
- Don't mark /etc/alternatives files as %%config as that would lead
  to stale symlinks on uninstall
* Wed Nov  6 2019 Dr. Werner Fink <werner@suse.de>
- Avoid racy bash code on waiting on find in do_mandb (boo#1155879)
* Sun Nov  3 2019 Dr. Werner Fink <werner@suse.de>
- Use %%{_prefix}/lib for tmpfiles.d directory to avoid to get this
  nonexecutable location below new location of %%{_libexecdir}
* Tue Jun 11 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(systemd) instead of systemd: allow OBS to
  shortcut the build queues by allowing usage of systemd-mini
* Tue Apr 30 2019 Dr. Werner Fink <werner@suse.de>
- Make systemd timers and services optional but hold them enabled
  as maybe in future all packages providing manual pages might use
  a posttrans scriplet to trigger a refresh of the man db (boo#1133762).
* Tue Apr 30 2019 lnussel@suse.de
- remove %%verify(not group) from /var/cache/man, the inconsistent
  permissions are fixed in the permissions package (boo#1133678)
* Fri Mar  8 2019 Dr. Werner Fink <werner@suse.de>
- Ah ... yes, manual pages are also provides by e.g. mandoc
* Thu Mar  7 2019 Dr. Werner Fink <werner@suse.de>
- Skip %%verify(not link mtime) from symbolic links %%_bindir even if
  those should not hurt but avoid superfluous verify messages
* Wed Mar  6 2019 Dr. Werner Fink <werner@suse.de>
- Minor corrections on %%ghost /var/cache/man and link to apropos
* Wed Mar  6 2019 Dr. Werner Fink <werner@suse.de>
- Use update-alternatives to allow that man(1), apropos(1), whatis(1)
  can be overwritten by an other package like mandoc
- Reintroduce wrapper for man(1) but without mapping to user man to
  be able to reset the PATH to the standard for any preprocessor
* Mon Nov 26 2018 Dr. Werner Fink <werner@suse.de>
- Update to man-db 2.8.4
  * Major changes since man-db 2.8.3:
  + Rely on decompressors reading from their standard input rather
    than redundantly passing them the input file on their command
    line.  This works better with downstream AppArmor confinement of
    decompressors.
  + Fix invalid syntax in tmpfiles.d/man-db.conf when configured with
  - -disable-cache-owner.
  + Make seccomp sandbox allow sched_getaffinity, sometimes used by
    xz.
  + Check for mandb_nfmt and mandb_tfmt in the manual page hierarchy
    as documented, not in the current directory.  This was broken by
    the working-directory-handling changes in 2.8.3.  Note that this
    change means that "man -l" will never use an external formatter
    (which was never documented behaviour and was surely a bad idea).
  + Make seccomp sandbox allow some shared memory operations across
    the board rather than just when ESET File Security is in use; the
    Astrill VPN seems to require something similar, and there are
    doubtless other such preload hacks.
  + Some versions of ESET File Security call msgget and msgsnd; if
    this program is in use, then allow those.
  * Major changes since man-db 2.8.2:
  + Make seccomp sandbox allow madvise, since that's used by lbzip2.
  + Make seccomp sandbox allow kill and tgkill outright, since groff
    uses kill to pass on signals to its child processes.
  + Make seccomp sandbox allow sibling architectures on
    x86/x86_64/x32, since people sometimes mix and match architectures
    there for performance reasons.
  + Fix version check in locale macro loading to tolerate groff
    release candidates.
  + man now only changes working directory in child processes, so
    never fails due to being unable to change back to its original
    working directory.
  + accessdb, apropos, and lexgrog no longer emit spurious gettext
    headers in their --help output when localised.
  * Major changes since man-db 2.8.1:
  + Make seccomp sandbox allow kill and tgkill when the signal is
    directed at the current process or one of its threads; this is
    needed by xz.
  + Make seccomp sandbox allow ioctl(fd, TIOCGWINSZ), since that's used
    by musl.
  + Work around the proprietary "ESET File Security" antivirus program in
    seccomp sandbox: if this is in use then we need to allow some
    socket-related system calls.
  + Work around the "snoopy" execve() wrapper and logger in seccomp
    sandbox: if this is in use then we need to allow some
    socket-related system calls.
  + Interpret EFAULT from seccomp_load as meaning that seccomp is
    unavailable, since this can be returned by some versions of
    qemu-user.
  * Major changes since man-db 2.8.0:
  + Fix seccomp sandbox build on Linux/POWER.
  + Fix manconv execution under seccomp when man is installed setuid.
  + Make seccomp sandbox allow mremap (used by iconv, for example).
  + configure now has a --without-libseccomp option to disable the use
    of seccomp even if the library is available.
  * Major changes since man-db 2.7.6.1:
  + Fix locale macro loading for Chinese to load the macro file
    corresponding to just the language part of the user's locale.
  + Honour --enable-cache-owner in generated systemd tmpfiles snippet
    rather than hardcoding "man".
  + If man adds prefixes to a page to handle such things as disabling
    hyphenation, then take account of those when looking for a
    preprocessor line at the start of the page.
  + Fix a segfault in 'man -D --help'.
  + Treat "\(en" as another synonym for "\-" in NAME sections.
  + Confine most subprocesses that handle untrusted data using
    seccomp.  This mainly deals with subprocesses that perform
    encoding conversions, (de)compressors, groff programs, and a few
    other odds and ends.  groff programs use a slightly more
    permissive filter since they need to create temporary files, so
    additional path-based confinement (e.g. using AppArmor) is still
    useful.
    If this goes wrong, then MAN_DISABLE_SECCOMP=1 can be set in the
    environment to disable it, but please report any such problem as a
    bug.
  + man now falls back to cat if the compile-time default pager is not
    executable.
  * Major changes since man-db 2.7.6:
  + Don't chmod CACHEDIR.TAG if it doesn't exist.
  + Correct installation of Swedish manual pages.
- Modify the patches
  * man-db-2.6.3-listall.dif
  * man-db-2.6.3-man0.dif
  * man-db-2.6.3-section.dif
  * man-db-2.7.1-firefox.dif
  * man-db-2.7.1-security4.dif
  * man-db-2.7.1-zio.dif
- Rename patch man-db-2.7.6.dif which is now man-db-2.8.4.dif
* Fri Nov  9 2018 Dr. Werner Fink <werner@suse.de>
- Add systemd timer service and its timer unit to refresh man
  data base daily without using cron (bsc#1115406)
* Mon Apr 16 2018 werner@suse.de
- Skip cron job for cleaning /var/cache/man as there exists
  /usr/lib/tmpfiles.d/man-db.conf
* Thu Dec  7 2017 kukuk@suse.de
- Add man-db-create.service to fill /var/cache/man at bootup
  if the directory is empty (required by FHS and for transactional
  updates).
- Don't fill /var/cache/man if it does not exist yet (needed for
  transactional updates).
- We don't need to package /var/cache/man, systemd-tmpfiles is
  creating it already for us.
* Wed Nov 29 2017 werner@suse.de
- Make /var/cache/man a real directory as in system-user-man the
  directory is gone
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Tue Nov 21 2017 werner@suse.de
- Require package man-pages at build time for testing
* Thu Feb 16 2017 werner@suse.de
- Use _libexecdir instead of _prefix/lib
* Sat Jan 21 2017 kukuk@suse.com
- Require user and group man
* Fri Dec 16 2016 werner@suse.de
- Update to version 2.7.6
  * Many bug fixes
  * man understands the <page>.<section> form on its command line,
    so for example 'man chmod.2' is now the same as 'man 2 chmod'
    (Contributed by Mihail Konev)
  * Document that 'man -K' searches page source, not rendered text
- Rename patch man-db-2.7.1.dif which becomes man-db-2.7.6.dif
- Port the patches
  man-MAN_POSIXLY_CORRECT-man1.dif
  man-db-2.6.3-chinese.dif
  man-db-2.6.3-listall.dif
  man-db-2.6.3-section.dif
  man-db-2.7.1-firefox.dif
  man-db-2.7.1-security4.dif
  man-db-2.7.1-zio.dif
- Add an rpmlintrc file man-rpmlintrc as we apply a patch
  on generated manual pages
- Do not wrap man anymore (boo#986211)
* Fri Jun 24 2016 werner@suse.de
- Give man(1) command a home that is let pager less(1) handle its
  history (boo#986211)
* Mon Mar 21 2016 bwiedemann@suse.com
- Add reproducible.patch to fix build-compare (bnc#971922)
* Mon Jun  8 2015 werner@suse.de
- Allow root to use man command within its home
* Fri May 29 2015 werner@suse.de
- Own /usr/lib/tmpfiles.d if not owned by package filesystem
* Thu May 28 2015 werner@suse.de
- Update to version 2.7.1
  For the first time since version 2.4.0, the database format has
  changed slightly, so you will need to run 'mandb --create' after
  installing the new version to rebuild your databases from scratch.
- Fixes
  * Various portability fixes for Solaris, contributed by Peter Bray.
  * man now runs correctly when its current working directory has been
    deleted.  (As a result of this fix, man-db now requires
    libpipeline >= 1.4.0.)
  * 'man -a' sends its prompts to /dev/tty rather than to stderr, and
    likewise reads replies from /dev/tty rather than from stdin.
  * Be more careful to avoid using or double-closing closed database
    handles.  Fixes test suite failures on some systems.
  * Patch the fdutimens function imported from Gnulib to work around a
    libc bug in GNU/Hurd.
  * Fix test suite in the case where the system supports
    high-precision timestamps but the file system containing the build
    directory does not.
  * lexgrog now filters terminal escape sequences out of cat pages
    before trying to parse them.
  * Tools that consider the terminal line length now prioritise the
    COLUMNS environment variable above the TIOCGWINSZ ioctl.
  * Manpath elements are no longer canonicalised before being inserted
    into the search path; this caused the use of incorrect catpaths in
    some cases.  This was broken by the LANGUAGE-handling fixes in
    2.5.4.
  * Remove test suite dependency on realpath(1).
  * Fix a test failure when configured with --enable-undoc.
  * Run the pager in man's original working directory rather than in
    the manual hierarchy.  (As a result of this fix, man-db now
    requires libpipeline >= 1.3.0.)
  * mandb only creates a cache directory tag if the catpath is
    different from the manpath, since it should only be created in
    directories that consist entirely of cached information.
- Improvements
  * Ship a systemd tmpfiles snippet to clean up old cat files after a
    week.
  * The modification time of manual databases is now simply stored in
    the mtime of the database files themselves, rather than using a
    special row.  This makes databases reproducible between
    otherwise-identical installations, as long as the underlying
    database has predictable behaviour.  As a bonus, man-db now uses
    high-precision timestamps to determine whether it needs to update
    databases.
  * Timestamps of manual pages are also now stored in the database
    with high precision and compared accordingly.
  * Files are now ordered by first physical extent before reading
    them, for substantial performance improvements in operations such
    as mandb and 'man -K'.
  * 'man -H' shows a better error message if no browser is configured.
  * zsoelim is now installed in $pkglibexecdir, to avoid clashes with
    other packages.
- Rename patches
  man-db-2.6.5-firefox.dif becomes man-db-2.7.1-firefox.dif
  man-db-2.6.5-security4.dif becomes man-db-2.7.1-security4.dif
  man-db-2.6.5-zio.dif becomes man-db-2.7.1-zio.dif
  man-db-2.6.5.dif becomes man-db-2.7.1.dif
* Thu Jul 31 2014 werner@suse.de
- The former change had added the patch man-MAN_POSIXLY_CORRECT-man1.dif
* Tue Jul 29 2014 auxsvr@gmail.com
- Added description of MAN_POSIXLY_CORRECT in man.man1,
  patch man-MAN_POSIXLY_CORRECT-man1.dif (bnc#786679)
* Tue Jun 10 2014 werner@suse.de
- Avoid messages on deleted cache directories bewlow /var/cache/man/
  that is tag them as %%ghost (bnc#882030)
- The former submit had rebased the patches
  man-db-2.6.3.dif
  man-db-2.6.3-security4.dif
  man-db-2.6.3-firefox.dif
  man-db-2.6.3-zio.dif
  which now had renamed to
  man-db-2.6.5.dif
  man-db-2.6.5-security4.dif
  man-db-2.6.5-firefox.dif
  man-db-2.6.5-zio.dif
  accordingly
* Tue Apr  8 2014 sweet_f_a@gmx.de
- Update to version 2.6.6
- Fixes since 2.6.3:
  * man(1) and catman(8) now document the default section list set at
    configure time.
  * Build fixes for Automake 1.13.
  * man-db 2.6.0 arranged to search the full manpath when expanding
    .so directives in manual pages (so that ".so name.1" works as well
    as ".so man1/name.1"), but this incorrectly did not take effect
    for manual pages that consist only of a .so directive.  This is
    now fixed.
- Improvements since 2.6.3:
  * The MANLESS environment variable is now treated as if it were a
    default value for the -r option to man: occurrences of the text
    "$MAN_PN" are expanded, and explicitly using the -r option
    overrides the default.
  * The (unfortunately still hardcoded) maximum length for paths to
    manual page hierarchies in the configuration file is now 511
    characters rather than 49.
  * MANPATH entries now undergo glob(7)-style wildcard expansion,
    allowing entries such as "/opt/*/man".
- Fixes since 2.6.4:
  * man's --warnings option works again on systems with versions of
    groff that support it (broken in 2.6.4).
  * man automatically falls back to C.UTF-8 and then en_GB.UTF-8 if
    trying to find a UTF-8 locale on a system without
    /usr/share/i18n/SUPPORTED.
- Fixes since 2.6.5:
  * apropos's --and option now works again; it was broken by the
    optimisations in 2.6.2.
  * Restore compatibility with Automake 1.10.
  * Improve support for translation of common elements of help
    messages.
  * Don't issue error messages when the database refers to a page that
    no longer exists.
  * Pass macro and hyphenation language tags to groff again (broken in
    2.6.5).
- Improvements since 2.6.5:
  * ./configure --with-override-dir=OVERRIDE arranges to look for
    manual pages in DIR/OVERRIDE before each path element DIR.
- rebase following patches:
  * man-db-2.6.3.dif
  * man-db-2.6.3-security4.dif
  * man-db-2.6.3-firefox.dif
  * man-db-2.6.3-zio.dif
- enable checks
* Thu Sep 12 2013 mvyskocil@suse.com
- Recommends groff-full to reduce dependencies (bnc#839717)
* Mon Jun 17 2013 werner@suse.de
- Just be able to print manual pages, that is require groff-full
- Be second owner of /usr/share/groff/site-tmac
* Mon Apr 22 2013 meissner@suse.com
- remove japanese manpages
* Tue Apr 16 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Mon Oct 29 2012 werner@suse.de
- Make shadowed manual pages accessible (bnc#786679)
* Tue Oct  9 2012 werner@suse.de
- Avoid double free of pointer internal_locale due dup onto
  pointer lang
* Thu Oct  4 2012 werner@suse.de
- Update to version 2.6.3
  * Build fixes for glibc 2.16 and Automake 1.12.
  * apropos prints an error message and returns non-zero when it finds
    no matches.  (Regression introduced in 2.5.1.)
  * The presence of a 64-bit GDBM database on the manpath no longer
    causes a 32-bit man process to exit with a fatal error.
  * apropos is much faster when run with many arguments.
  * whatis may be given the full path to an executable as an argument,
    in which case it will look up the base name of that executable in
    the appropriate parts of the manpath.
  * Translated manual pages are no longer displayed starting with a
    spurious blank line.
  * Fix double-free in mandb when encountering a symlink outside the
    manual hierarchy, thanks to Peter Schiffer.
  * Running 'man -w' (with a new --path alias) without a name now
    prints the manpath, for compatibility with other man
    implementations.  The vim viewdoc plugin makes use of this.
  * Fix a segfault when scanning links to empty pages.
  * Once we've seen at least one record in a page's NAME section,
    ignore any further records that don't include a whatis
    description, as they tend to be noise.
  * Ensure that the target of a symlink or .so chain is always recorded
    as a real page.
  * Read a user-specified configuration file even if HOME is unset.
  * Fix failure to display manual pages in some encodings when
    installed setuid.
  * Wrap long table cells in man(1), fixing test failures with groff
    1.21.
  * If an explicit section is passed to man, then pages that match
    that section exactly will be preferred over pages that only have
    that section as a prefix.
  * Fix a segfault when 'man -K' tries to display certain pages.
  * Fix a segfault in some situations when processes are killed by
    SIGHUP, SIGINT, or SIGTERM.
  * As promised in the release notes for man-db 2.5.8, man-db no
    longer ships its own copy of libpipeline
    (http://libpipeline.nongnu.org/).  You must build and install that
    library separately.
  * Search the full manpath when expanding .so directives in manual
    pages.  As part of this, '.so name.1' should now work as well as
    '.so man1/name.1'.
  * lexgrog handles roff named glyphs and perldoc strings in NAME
    sections.
  * man no longer starts a pager if standard output is not a tty.
  * The -s option to whatis and apropos now takes a colon- or
    comma-separated list of sections, similar to 'man -S'.
  * mandb error output is neater when stderr is not a terminal.
  * Add basic support for the implementation of nroff/troff in the
    Heirloom Documentation Tools.  Title lengths are not properly set
    as yet, and many features are untested.
  * mandb removes cat* and NLS subdirectories of cat directories whose
    corresponding man directories no longer exist.
  * mandb forces SIGPIPE back to its default disposition on startup,
    to avoid noisy output in case it was started in a context where
    SIGPIPE was ignored.
  * SECTION entries in a user configuration file now override those in
    the system configuration file, rather than appending to them.
  * The default less prompt now includes "(press h for help or q to
    quit)" to help novices find their way around.
  * man-db may now be built to use Berkeley DB version 5
    (--with-db=db5).
  * Fix assertion failure on 'man -l' with an uncompressed page and
    any of --no-hyphenation, --no-justification, or a non-English
    page.
  * Try underscore-separated subpages as well as hyphen-separated
    ones, thanks to Tanguy Ortolo.
  * Build libman and libmandb as shared libraries, reducing installed
    footprint by about 200K (at least on GNU/Linux).
  * Warnings about unrecognised locales are now suppressed if the
    DPKG_RUNNING_VERSION environment variable is set (i.e. man-db is
    running within a Debian package's maintainer script), since the
    system locales are often out of sync with the C library in that
    context.  Thanks to the Debian Perl maintainers for the idea.
  * Allow building with an external libpipeline
    (http://libpipeline.nongnu.org/), which has been split out from
    man-db.  This is a transitional measure: a future version of
    man-db will stop shipping its own copy of libpipeline.
  * mandb should no longer repeatedly rescan manual page hierarchies
    when a whatis entry turns into a broken link.
  * If a subprocess exits before man manages to read all the output
    from it, it now drains the output file descriptor rather than
    immediately discarding it.
  * If /usr/share/i18n/SUPPORTED is available, man attempts to use it
    to ensure that LC_CTYPE is set to an appropriate locale for the
    selected character set when invoking col. This fixes 'LANG=C man
  - E UTF-8', as used by lintian.
  * Fix possible mandb crash when MAN_MUST_CREATE is unset.
  * man can now tell nroff to disable justification if the
  - -no-justification option is used.
  * If the full path to an executable is given as an argument, man
    will try looking up the corresponding manual page in the
    appropriate part of the manpath, rather than just trying to format
    the text of the executable as a manual page.
  * In the GNU manual hierarchy layout, search man<sec><ext>
    directories as well as just man<sec> (e.g. /usr/share/man/man3p as
    well as /usr/share/man/man3).
  * By request, man now prefers getting a page from the best manual
    section over getting a page in the correct language.
  * All programs now support a MAN_DEBUG environment variable which
    can be used in place of the -d/--debug option. This is useful in
    some situations where a program is being called deep in a process
    tree.
  * Add support for emulating pipe() with socketpair(), which is
    faster on some systems; thanks to Werner Fink of SUSE.
  * Cat pages are now always saved in UTF-8, and converted to the
    proper encoding at display time, which means that cat pages can
    now be saved regardless of locale. Note that a consequence of this
    is that cat pages now include formatting information (e.g.
    overstriking) and need to be run through col(1) before display.
  * Exact-section database lookups were incorrectly returning all
    database entries whose section names were prefixes of the
    requested section name. In some cases this could confuse mandb
    into never believing that the database was up to date.
  * Fix handling of pages with comma-separated names ("foo, bar,
    baz") in their NAME sections, broken by a change in 2.5.0 (!)
    to ignore manual page names containing spaces.
  * Fixed a buffer overflow in the pipeline library's line-reading
    functions. I don't believe this to be exploitable: at worst we
    might believe that there's some garbage at the end of manual pages
    (whose contents are untrusted anyway) and this bug typically
    resulted in a failed assertion the next time anything tried to
    read a line.
  * Plugged two substantial memory leaks in the pipeline library.
  * whatis and apropos only display any given manual page, or pointers
    to it, once.
  * man now sets less(1)'s environment up correctly for manual pages
    encoded in CP1251.
  * manconv no longer confuses situations such as "this UTF-8
    character is not representable in the target encoding" with "this
    text is not in UTF-8".
  * The default configuration file now includes section 0, used on
    some systems to document C library header files.
  * 'make check' now passes in the presence of a UTF-8-aware col, such
    as that in util-linux-ng.
  * The 'man -K' option is now supported to search the full text of
    all manual pages. This was inspired by a similar option in the
    other man package (currently at version 1.6f) currently maintained
    by Federico Lucifredi and formerly by Andries Brouwer, but I took
    advantage of man-db's pipeline library to implement it entirely
    in-process, without having to start a separate grep process for
    every manual page. In my tests with fairly typical searches across
    variously all manual pages or just one section, man-db's
    implementation ran between 3 and 10 times faster.
  * Database directories are now only created when there are
    corresponding manual page directories, not just because they're
    mentioned in the configuration file.
  * By default, man will now try to interpret pairs of manual page
    names given on the command line as equivalent to a single manual
    page name containing a hyphen (e.g. 'man foo bar' => foo-bar(1)).
    This supports the common pattern of programs that implement a
    number of subcommands, allowing them to provide manual pages for
    each that can be accessed using similar syntax as would be used to
    invoke the subcommands themselves. Suggested by H. Peter Anvin,
    Federico Lucifredi, and others on the git mailing list.
  * The build process is now quieter by default. Use './configure
  - -disable-silent-rules' or 'make V=0' if you don't like this or
    your make(1) doesn't support the non-standard extension required.
  * manconv understands a wider range of Emacs-style coding tags.
  * Recommendations to change MAN_DB_CREATES, MAN_DB_UPDATES, and
    MAN_CATS #define options in manconfig.h have been replaced by new
    configure options --enable-automatic-create,
  - -disable-automatic-update, and --disable-cats respectively. Note
    that automatic user database creation is now off by default, as it
    is often too slow for the usefulness it adds; use
  - -enable-automatic-create to enable it.
  * Pages that declare a non-default encoding in their preprocessor
    lines are now handled correctly.
  * man-db's 'make check' now tests that all its own manual pages
    format without errors or warnings from groff, to ensure a
    better-quality release.
  * lexgrog now stops on any unrecognised roff request, rather than
    continuing and often littering the database with garbage.
  * man no longer requires both standard input and standard output to
    be terminals in order to use the terminal line length. The line
    length from standard output is preferred if available.
  * The manpath was built completely wrongly when multiple entries
    were present in LANGUAGE: duplicates were handled strangely, and
    languages were effectively iterated in reverse order. It should be
    rather more sensible now.
  * The MAN_KEEP_STDERR environment variable can now be used to
    override man's default of discarding stderr when stdout is a
    terminal.
  * Handling of terminal widths for cat pages is now configurable,
    using the MINCATWIDTH, MAXCATWIDTH, and CATWIDTH configuration
    file directives.
  * 'man -a' now detects duplicate manual page candidates more
    reliably, and sorts them better.
  * Belarusian, Estonian, Greek, Latvian, Lithuanian, Macedonian,
    Romanian, Slovenian, and Ukrainian pages are now supported.
  * man can now search for pages using regular expressions (with
  - -regex) or shell wildcards (with --wildcard). By default this
    searches both page names and descriptions, like apropos, but if
    the --names-only option is used then it searches page names only,
    like whatis.
  * man can now tell nroff to disable hyphenation if the
  - -no-hyphenation option is used.
  * man-db already searched for manual pages in ../man and man
    directories relative to each $PATH component; it now searches in
    ../share/man and share/man directories too.
  * Groff 1.20 was recently released, including the 'preconv'
    preprocessor. Although man-db has supported preconv to some extent
    since 2.4.4, man-db's configure now detects its presence and
    infers that groff supports Unicode input using it; man also now
    takes slightly better advantage of preconv than before.
  * Per-locale groff macros are now loaded if possible, allowing us to
    take advantage of such things as localised versions of predefined
    strings and language-aware hyphenation. This only works with Groff
    1.20.2 or better (not yet released), since earlier versions did
    not allow us to suppress warnings in the event that the
    appropriate macro file is not available.
  * Cleaned up a number of possible crashes, memory leaks, and missing
    error checks found by the Coverity Scan project.
  * Fix build if MAN_CATS is undefined.
  * If the LINGUAS environment variable is set while running
    configure, it now controls building and installation of localised
    manual pages as well as program translations.
  * The LANGUAGE environment variable is now tokenised properly,
    rather than only taking the first two characters of each element.
  * Fix build if --disable-nls is used or iconv is not available.
  * man now correctly propagates the exit code of whatis or apropos
    when called with the -f or -k option respectively.
  * A number of inconsistencies and readability problems with man-db's
    own manual pages have been cleaned up, thanks mainly to Yuri
    Kozlov.
  * Reduce the number of warnings emitted when using an unrecognised
    locale.
  * manconv and zsoelim are now called internally rather than by
    executing external programs, to improve performance.
  * man-db now uses GDBM (--with-db=gdbm) in preference to Berkeley DB
    (--with-db=db or --with-db=dbN where N is 1, 2, 3, or 4) by
    default, since hardware improvements have rendered Berkeley DB's
    speed advantages negligible for our purposes and the relatively
    frequent SONAME and on-disk format changes are not worth the
    hassle. Distributors should note that if they follow this change
    then they will need to arrange for databases to be rebuilt on
    upgrade to this version.
  * Duplicate manual page hierarchies due to symlinks (e.g. /usr/man
  - > /usr/share/man) are detected and removed from the search order.
  * A locale modifier (e.g. @latin) in a directory name must now match
    the locale if the former is set, in addition to the language and
    territory.
  * Bare .so includes (e.g. ".so foo.1" rather than ".so man1/foo.1")
    now work, although only within the same manual page hierarchy for
    now.
  * 'man -H' (without a browser argument) was completely broken in
    2.5.1 and is now fixed.
  * man no longer breaks in Japanese locales when using less as a
    pager.
  * The --encoding option to man can now take a true character
    encoding rather than a *roff device; the latter was an unreliable,
    inflexible, and awkward way to select an output encoding. The old
    semantics are still supported for backward compatibility.
  * Whatis parsing stops at .ie or .if conditionals.
  * CJK locale specifications where the codeset component is
    equivalent to but not stringwise-identical to UTF-8 (e.g.
    zh_CN.utf8) are handled better.
  * man(1)'s OPTIONS section is ordered more comprehensibly.
  * apropos, lexgrog, man, mandb, and whatis ignore encoding
    conversion errors for the last possible encoding of the source
    page. This helps, for example, with pages including misencoded
    non-ASCII names of authors; it usually seems better to allow these
    pages to pass with small errors than to break them entirely.
* Mon Oct  1 2012 werner@suse.de
- Add ChangeLog and COPYING to documentation (bnc #777385)
* Tue Sep  4 2012 coolo@suse.com
- move man page directories to filesystem
* Mon Jul  2 2012 coolo@suse.com
- merge the automake 1.12 patches
* Thu Jun 28 2012 i@marguerite.su
- fix build for openSUSE.
  * AM_PROG_AR
- fix 12.2 builds
  * replace depreciated am_prog_mkdir_p with ac_prog_mkdir_p.
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Sun Dec 25 2011 coolo@suse.com
- cleanup spec file
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu May 26 2011 werner@suse.de
- man requires glibc-locale otherwise manconv does not work
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Fri Apr 30 2010 werner@suse.de
- Add a hint how to avoid the listall default behaviour of man
* Sun Dec 13 2009 jengelh@medozas.de
- enable parallel building
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Sep 21 2009 crrodriguez@suse.de
- tag localized man pages correctly
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Aug  3 2009 werner@suse.de
- Remove catman directories from /var/cache (bnc#527434)
* Fri Jan 16 2009 werner@suse.de
- Add ../share/man/ to manpath expansion mentioned by
  Matt_Domsch@dell.com, done for man_db by Colin Watson
* Fri Nov 28 2008 werner@suse.de
- For listall patch: add support for multiple man pages in the
  same section (bnc#448283)
- Fix bug in listall patch: initialize variable len as this may
  break on some system otherwise.
* Thu Nov 20 2008 werner@suse.de
- Skip mandocdb workaround as groff now works in UTF-8 (bnc#446710)
- Replace pipe(2) with socketpair(2) to speed up mandb (bnc#381830)
* Thu Oct  2 2008 werner@suse.de
- Fix option handling for renice in cron script (bnc#431027)
* Tue Aug 12 2008 werner@suse.de
- Update to version 2.5.2
  * `man -H' (without a browser argument) was completely broken in
    2.5.1 and is now fixed.
  * man no longer breaks in Japanese locales when using less.
  * The --encoding option to man can now take a true character
    encoding rather than a *roff device; the latter was an
    unreliable, inflexible, and awkward way to select an output
    encoding. The old semantics are still supported for backward
    compatibility.
  * Whatis parsing stops at .ie or .if conditionals.
  * CJK locale specifications where the codeset component is
    equivalent to but not stringwise-identical to UTF-8 (e.g.
    zh_CN.utf8) are handled better.
  * man(1)'s OPTIONS section is ordered more comprehensibly.
  * apropos, lexgrog, man, mandb, and whatis ignore encoding
    conversion errors for the last possible encoding of the source
    page. This helps, for example, with pages including misencoded
    non-ASCII names of authors; it usually seems better to allow
    these pages to pass with small errors than to break them
    entirely.
* Thu Jun  5 2008 werner@suse.de
- Show the user if there are more than one manual page found for
  the stated item (fate#303433)
* Tue May 13 2008 werner@suse.de
- Avoid tab stops in section names
* Wed Apr 23 2008 werner@suse.de
- Use speedup for bnc#381830  only in mandb as man would be break
- Avoid trouble with -Wl,--as-needed therefore fore -lbz2 and -lz
* Tue Apr 22 2008 werner@suse.de
- Make libzio interface smarter, that is if used only for simple
  decompression do not use a pipe (saves 30%% mandb run time)
  (bnc#381830)
- Make cron.daily.do_mandb smarter, that is check if anything
  has changes in the global manual paths that needs to run mandb
  (bnc#381830)
- Update to bug fix version 2.5.1
  * The manual is now built automatically, avoiding some ordering
    problems on 'make distclean'.
  * Manual pages are converted to the proper input encoding for troff
    output as well as nroff output.
  * The -t, -T, -X, and -Z options to man work again; in 2.5.0, they
    read input from stdin rather than from the manual page.
  * apropos and whatis no longer segfault when given an explicit
    locale using -L.
  * man now understands that groff's ascii device takes ASCII input,
    not ISO-8859-1.
  * man no longer discards stderr when writing to a file or a pipe;
    this was broken by an overenthusiastic change in 2.5.0.
  * manconv now falls back to the next encoding in its list if any
    characters in an entire 64KB block fail to decode using the
    current encoding, as was originally intended.
  * manconv is more careful about extracting coding: directives from
    manual pages.
  * Ctrl-C and Ctrl-\ now work again at the prompt issued by 'man -a'.
  * There is a new --with-sections configure option to change the
    default value of SECTION in the configuration file.
  * Automake is now used to generate Makefiles. Among other things,
    this fixes VPATH builds and some bugs in dependency generation,
    and should allow building with non-GNU versions of make.
  * man-db now uses the Gnulib portability library, allowing the
    removal of earlier haphazard portability code. While this results
    in a somewhat larger source distribution, it makes man-db easier
    to maintain and should make it easier to build on systems to which
    the maintainer does not have access.
  * In the process of switching to Gnulib, the last vestiges of
    pre-C89 support have been removed; they were documented to be
    broken anyway.
  * If the MANROFFOPT environment variable is set, man now appends its
    value to the *roff command line.
  * man now accepts a --recode option to output a source manual page
    converted to a specified encoding.
  * For compatibility with System V, man accepts -s as an alias for
  - S, and permits sections to be comma-separated as well as
    colon-separated.
  * man now accepts a --warnings option to enable groff warnings.
* Tue Feb 26 2008 werner@suse.de
- Ensure to find local manual pages even in sub directories
* Wed Jan 30 2008 werner@suse.de
- Make mandb cron job ionice bnc#356792
- Avoid assert on wrong locale man path
- Do mix bits of get_catpath() with hash tags in man db files
* Fri Jan 18 2008 mkoenig@suse.de
- Fix path in sysconfig.cron-man [#350542]
* Mon Jan  7 2008 werner@suse.de
- Remove suid root from wrapper as we do not cache manual page
  anymore (bug #351988)
* Thu Dec 13 2007 werner@suse.de
- Add workaround for gettext 0.17
* Mon Dec 10 2007 werner@suse.de
- Update to man-db 2.5.0-4
  * No temporary files anymore due usage of pipes
  * Our libzio patch is simply to add due this new API
  * Better UTF-8 support
  * Disable straycats for now
- Add sample script mancoding to show how to use encoding tag
* Wed Sep 19 2007 werner@suse.de
- Be sure that e.g. /usr/share/man/man3p/open.3p.gz is found before
  /usr/share/man/man3/open.3pm.gz by "man 3p open" (bug #310498)
* Fri Jul 27 2007 mfabian@suse.de
- change BuildRequires to make it build in the openSUSE build
  service for versions <= 10.2 as well.
* Thu Jul 26 2007 mfabian@suse.de
- Bugzilla #292412 comment #47: accept both UTF-8 an legacy
  encodings in the man-page sources for Japanese and Chinese
  as well.
* Wed Jul 25 2007 mfabian@suse.de
- Bugzilla #292412 comment #30 and #39: improve Chinese patch.
- use %%find_lang macro
* Thu Jul 19 2007 werner@suse.de
- Add Chinese support to man (bug #292412)
* Wed Jul 18 2007 werner@suse.de
- Add workaround for html browsers which do their job in
  background: do not remove the temporary files to fast (#280613)
- Update to debain patch level 6 which
  * includes bug fix for CVE-2006-4250 (bug #262747)
  * includes french manual pages
* Tue Apr 17 2007 werner@suse.de
- Fix heap buffer overflow (CVE-2006-4250, bug #262747)
* Mon Mar 26 2007 rguenther@suse.de
- Add libbz2-devel and libzio-devel BuildRequires
* Wed Mar 21 2007 rguenther@suse.de
- Remove unused util-linux BuildRequires, added less, zlib-devel
  and gdbm-devel BuildRequires
* Thu Feb 15 2007 werner@suse.de
- Remove not used path elements (X11R6, openwin, allman) (#245692)
* Fri Feb  9 2007 werner@suse.de
- Make it build without root privileges, loosing time for texlive
* Mon Jan 29 2007 sbrabec@suse.cz
- Removed references to /opt/gnome.
* Mon Sep  4 2006 rguenther@suse.de
- Remove unused sharutils dependency.
* Mon Sep  4 2006 rguenther@suse.de
- Remove lynx build dependency.  Set default for AC_PATH_PROG for
  lynx to /usr/bin/lynx.
* Mon Aug  7 2006 werner@suse.de
- Make it work even with new gettext package
* Thu Aug  3 2006 sndirsch@suse.de
- read also manual pages in man4x subdirectories; required for
  conflicting 'mouse' manual page and i810 driver manual page,
  which has been moved to man4x directory
* Wed Jun 14 2006 werner@suse.de
- Update to man-db 2.4.3 patchlevel 3 to get the first part of bug
  [#183796] fixed.
- Change lex scanner to set sperator ony onece per whatis/apropos
  line to get second part of bug #183796 fixed
- Support several language types/locations
- Do not fail on verbatim macro of perl man pages on whatis/apropos
- Do not fail on DOS formated manual pages on whatis/apropos
* Fri Apr  7 2006 werner@suse.de
- Do not reset terminal if stdout is not a tty (bug #152793)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Wed Dec 14 2005 werner@suse.de
- Make cron job files word readable (bug #138549)
* Tue Dec 13 2005 werner@suse.de
- Add section 0 for header files
* Wed Jun  1 2005 kukuk@suse.de
- Make cron.daily script names LSB conform
* Thu Feb 10 2005 mfabian@suse.de
- Bugzilla #50694: add another request to tmac.andocdb:
    ".  char  ` \N'96'"
  makes sure U+0060 (GRAVE ACCENT) doesn't get replaced by
  U+2018 (LEFT SINGLE QUOTATION MARK)
* Wed Sep 22 2004 werner@suse.de
- Use safe-rm for deleting straycats (bug #45612, comment #14)
* Thu Sep  9 2004 werner@suse.de
- Be ready for flex-2.5.31
* Wed Apr 21 2004 werner@suse.de
- Use libzio together with zlib and libbz2 to support bz2 manual
  pages to avoids pipe()/fork()/execve() calls in mandb/man.
* Tue Mar 16 2004 werner@suse.de
- Activate path for bug #35821 due its fixed now.
* Fri Mar 12 2004 werner@suse.de
- Be prepared for bug #35821
* Thu Sep  4 2003 werner@suse.de
- It seems that basename(3) results shouldn't be freed even if
  the manual page says they should. (bug #30093)
* Fri Aug 29 2003 werner@suse.de
- Add workaround for less using xselection even if no -A is
  specified for bug #29612. Nevertheless less has to be fixed.
* Wed Aug 20 2003 werner@suse.de
- Update to 2.4.1-13 security only, due missed fixes in previous
  patches.
* Fri Aug 15 2003 kukuk@suse.de
- Use same permissions for man/mandb as in permissions package
* Thu Aug  7 2003 werner@suse.de
- YaSP: Added more security
- Ensure that no version conflict happens during db purge (#28414)
* Fri Jul 11 2003 werner@suse.de
- Update to 2.4.1-10
- Security fix: create the temporary database exclusive
* Mon Jul  7 2003 werner@suse.de
- Security fix (bug #27474)
* Fri Jun 20 2003 ro@suse.de
- fix build with current gettext
* Thu Jun 12 2003 olh@suse.de
- disable sync call in install section
* Thu Jun 12 2003 kukuk@suse.de
- /var/cache/man is part of filesystem
* Fri Jan 17 2003 mfabian@suse.de
- add another request to tmac.andocdb:  ".  char  ' \N'39'"
  makes sure U+0027 (APOSTROPHE) doesn't get replaced by
  U+2019 (RIGHT SINGLE QUOTATION MARK)
* Sun Jan 12 2003 mfabian@suse.de
- fix header of de.po to enable gettext to convert to locale
  encoding
- fix and update some translations in de.po
* Wed Jan  8 2003 werner@suse.de
- bug #22628 -- add missed meta data within sysconfig file
* Mon Dec  2 2002 werner@suse.de
- Make compress local manuals work if placed in a writable dir for
  the user man (bug #22215).
* Fri Oct 11 2002 mfabian@suse.de
- add another request to tmac.andocdb similar to the one
  in the last changelog entry to make the regular minus '-'
  (without backslash) get rendered as U+002D (HYPHEN-MINUS)
  in man-pages as well.
* Fri Sep  6 2002 mfabian@suse.de
- add the two lines
  .if '\*[.T]'utf8' \
  .  char \- \N'45'
  to /usr/share/groff/site-tmac/tmac.andocdb in order to get
  U+002D (HYPHEN-MINUS) instead of U+2212 (MINUS SIGN) as the
  minus sign in front of options in man-pages rendered in UTF-8
  locales. U+2212 (MINUS SIGN) makes searching in man-pages for
  options unnecessarily difficult.
* Fri Aug 23 2002 werner@suse.de
- Use LESSCHARSET=japanese-euc for japanese to support even konsole
  (bug #18222)
* Fri Aug 16 2002 werner@suse.de
- Add PreReq (bug #17927)
* Wed Jul 31 2002 poeml@suse.de
- add ssl to the list of man sections (bug #17239)
* Sat Jul 27 2002 adrian@suse.de
- fix neededforbuild
* Wed Jun  5 2002 ro@suse.de
- run suse_update_config for subdir tools
* Fri May 10 2002 werner@suse.de
- Use buildroot (fix bug #12158)
- Don't cache utf8 formatted man pages (fix bug #16067)
* Thu Apr  4 2002 ro@suse.de
- fix for autoconf LIBOBJS vs AC_LIBOBJ
* Wed Mar 27 2002 werner@suse.de
- Add space between grep command and its options for whatis
  text file fallback.
* Thu Mar 14 2002 werner@suse.de
- Use nroff asci8 character set for korean (nippon does not work).
* Wed Feb  6 2002 ro@suse.de
- sysconfig/cron_daily -> sysconfig/cron
* Thu Jan 31 2002 werner@suse.de
- Add security patch from Olaf Kirch
* Thu Jan 31 2002 ro@suse.de
- moved cron.daily scripts do_mandb and clean_catman to this pkg
* Fri Jan 11 2002 werner@suse.de
- Add security patch from Thomas Biege
* Thu Dec 20 2001 werner@suse.de
- Check existence of user man
* Tue Sep 25 2001 werner@suse.de
- Close nonsens bug report #9419
* Tue Sep 18 2001 werner@suse.de
- Avoid possible crash in mandb
* Fri Aug 31 2001 werner@suse.de
- I vote to remove strtok() from ANSI-C: Use strsep() within
  pathappend() because thew calling function add_nls_manpath()
  uses strtok().
* Wed Aug 29 2001 werner@suse.de
- More work on the whatis data base storage
* Tue Aug 28 2001 werner@suse.de
- Whatis: Avoid error messages caused by buggy manual pages
  to see the wrong man pages one may use -v for verbose
* Thu Aug 16 2001 werner@suse.de
- Global UTF-8 handling instead of two different ways
* Wed Aug 15 2001 werner@suse.de
- Better UTF-8 man page handling: use curent locale even if we
  overwrite man page locale.
- Sometime there is no man page path for local man page files,
  therefore force language if not found.
* Mon Aug 13 2001 werner@suse.de
- Initialize variable used in lexgrog.l
* Mon Jul 30 2001 werner@suse.de
- Update to vesion 2.3.19deb4.0
- Port libz patch to this version
- Map UTF-8 man pages to appropiate groff command
- Make it work
* Sun Jun 17 2001 bk@suse.de
- new location of tmac files is /usr/share/groff/site-tmac,
  needed for groff 1.17 and does not work with older versions
* Thu Jun  7 2001 werner@suse.de
- Fix autoconf trouble
* Wed May 16 2001 werner@suse.de
- Make xcopy more handy (bug#8499)
* Tue May 15 2001 werner@suse.de
- Fix segfault on option -S parser
* Sat Apr 21 2001 schwab@suse.de
- Fix inapproriate mixing of pointer and integers.
* Mon Apr  9 2001 werner@suse.de
- Make it work
* Fri Apr  6 2001 werner@suse.de
- Use own tmac groff files to avoid page headers and footers
  on ttys only
* Tue Mar 20 2001 werner@suse.de
- Avoid deleting of data bases if we've newer version around
* Mon Mar 19 2001 werner@suse.de
- Remove data bases at install time
* Mon Mar 19 2001 werner@suse.de
- Update to 2.3.17-3.2
  * Port our patches and bugfixes to this new version
  * Change the wrapper to use setre(r|g)id and use
    this wrapper suid root
* Thu Feb  8 2001 werner@suse.de
- Avoid error() call without format
* Mon Dec 11 2000 werner@suse.de
- Correct depth level of patch
* Mon Dec 11 2000 werner@suse.de
- Make `setlocale'zing more reliable accordingly to Andreas
  Jaeger.
* Sat Dec  9 2000 mfabian@suse.de
- replaced all setlocale(LC_MESSAGES,"") with
  setlocale(LC_MESSAGES,"") *and* setlocale(LC_CTYPE,"").
  After the upgrade to Glibc 2.2, 8 bit characters in the
  French, Czech, and Japanese messages were displayed as "?".
  Changing the setlocale calls in the above way fixed it.
  Messages in all languages now display correctly again.
  First I replaced all setlocale(LC_MESSAGES,"") by
  setlocale(LC_ALL,""), but this causes problems. In that case,
  the messages display correctly, but  "LANG=ja_JP man man"
  incorrectly displays the English manpage. Strange.
  When using both setlocale(LC_MESSAGES,"") *and*
  setlocale(LC_CTYPE,"") but not setlocale(LC_ALL,""),
  everything seems to work correctly.
* Wed Dec  6 2000 bk@suse.de
- added %%dir /usr/share/man/{de,es,it,ja}+man[158] to file list
* Fri Sep 15 2000 pthomas@suse.de
- Add 3C++, 3C++std and 8C++ to the list of man sections, the
  Compaq man pages for C++ use these.
* Thu May 25 2000 werner@suse.de
- Fix the man path problem (hint from Michael Reichardt
  <mrabuse@adlatus.muc.de>)
- Make mandir depending on the RPM macro %%_mandir
- Make zsoemlin zlib interface functions more compatible to cookie
  I/O functions (type changed in new glibc 2.1 and higher)
* Thu Mar 16 2000 werner@suse.de
- Make lexgrog knowing the japanese multibyte string of section NAME
- Make flex use memory aligned tables.
* Wed Mar  8 2000 werner@suse.de
- Security fix in straycats: Check if we got a temporary file!
* Thu Mar  2 2000 ro@suse.de
- added usr/share/man/allman
* Tue Dec 14 1999 werner@suse.de
- New version 2.3.10-69s
  * better NLS support
- Add all languages to /etc/manpatch.config before english default
- Make mandb usable only for root (avoid DOS attacks)
* Fri Nov 26 1999 ro@suse.de
- printout full path-name on check
* Fri Nov 26 1999 ro@suse.de
- patched configure.in to prefer gdbm
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Sep  6 1999 ro@suse.de
- removed (now) conflicting redeclarations from zsoelim.l
* Thu Sep  2 1999 werner@suse.de
- Make man.c work again
- Use RPM_OPT_FLAGS
* Mon Aug 30 1999 werner@suse.de
- Few simple changes
  * drop privileges before chdir back into current directory
  * do not search for local man page if not given `-l'
* Mon Jul 19 1999 bs@suse.de
- fixed file list (/var/cache/man)
* Thu Jul 15 1999 werner@suse.de
- Don't use carriage return but newline in messages.
* Wed Jul 14 1999 kukuk@suse.de
- Fix %%pre section (use rm -rf)
* Mon Jul 12 1999 werner@suse.de
- Add allman sub tree to fsstnd tree
* Fri Jul  9 1999 ro@suse.de
- fixed filelist
* Tue Jul  6 1999 werner@suse.de
- Update to debian version 2.3.10-69i
  * Change from /var/catman/ to /var/cache/man/
  * Make /usr/share/man/ possible
  * Buildin NLS support
- Fix some debian bugs (sig handlers!)
- Add SuSE bug fixes (sig handler) and zlib feature
* Wed Jun 30 1999 werner@suse.de
- First changes for SuSE 6.2
  * Use fopencookie in zsoelim if glibc 2.1 or higher to avoid any
    possible link attack in /tmp/
  * Kill all possible childs (e.g. gunzip) of zsoelim for glibc 2.0
    to be able to unlink the temporary files during signal handling.
  * Use better sig and exit handling
* Fri Jun  4 1999 werner@suse.de
- Fix security leak in zsoelim
- Set sig and exit handler for removing temporary files
- ToDo: use libz instead of gzip
* Mon May  3 1999 ro@suse.de
- removed forgotten debug message
* Thu Mar 11 1999 werner@suse.de
- Use -Tlatin1 if eqn is geqn
- Remove the index.bt's in /var/catman before being installed
- Support stupid manual pages using .\" instead of '\" for
  preprocessor cockies
* Wed Mar 10 1999 werner@suse.de
- Use db2 if available
* Wed Mar 10 1999 werner@suse.de
- Work around of a buffer/pointer cludge of strncat and strncpy
  (glibc/axp)
- Make CAT_FILE work
- ToDo: libdb1 is broken on axp
* Wed Feb 10 1999 werner@suse.de
- Fix the SIGHUP/SIGTERM bug
- Use seteuid for LINUX_VERSION_CODE >= ((1<<16)+(1<<8)+37)
- Remove temp files for man -l even if signaled
- Fix some more possible SIGSEGV's
* Tue Sep 29 1998 ro@suse.de
- restarted from stable-man:
    use usr/include/db1 and libdb1  for db lib
    added HAVE_STRSEP to include/config.h.in (this file is broken)
    libdb/Makefile.in, src/Makefile.in : removed -I- from CFLAGS
* Fri Aug  7 1998 bs@suse.de
- added catman dirs for es, fr & it to file list.
* Thu Aug  6 1998 bs@suse.de
- added es, fr & it.
* Wed Jul 15 1998 bs@suse.de
- fixed /usr/man/allman/de
* Wed Apr 22 1998 werner@suse.de
- Fix preprocessor handling:
  was missed since libz was used instead of gzip -dc
* Thu Mar 19 1998 werner@suse.de
- Use lib(g)z for mandb
  * no temporary nroff files for parsing of the manual pages
  * handle only the first 4096 bytes from the first .SH down
  * now zsoelim gets the gezipped man page without extension
  instead a temporary nroff file
  * extend lexgrog.l-2.4a to catch most pages as possible
  * add -funroll-loop to the compile options, use -O2
* Fri Jun  6 1997 bs@suse.e
- added allman stuff
